=================
rpi_ip_bot_client
=================

This is the client side of Telegram `@rpi_ip_bot <http://telegram.me/rpi_ip_bot)>`_.

This bot was designed to help you track IP-address of your Raspberry Pi 3 or any other connected device if, for some reasons, it doesn't have static IP, isn't connected to VPN and you're too lazy to scan network or get into router control panel every time you need to get the remote access to your Linux device.

`Telegram bot description <https://goo.gl/4OvT4j>`_

Installation
------------

From PyPI:

*pip install rpi_ip_bot_client*

From this repository:

*git clone https://github.com/eugene-babichenko/rpi_ip_bot_client.git*

*cd rpi_ip_bot_client*

*pip install .*

Usage
-----

To install the script type *rpiipbot install <TOKEN>*, where <TOKEN> is one of the tokens, generated by the bot.

If you want to stop using the bot on this machine, just type *rpiipbot uninstall*.

By default the script is installed to */etc/network/if-up.d* so it's automatically run when any network connection is present.
To install it to another directory pass *--dir <dirname>*.
